==> firexcode-0.7.4.tar.gz: lib/src/Swipper/Swipe_To.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/physics.dart';

enum SwipePosition {
  SwipeLeft,
  SwipeRight,
}

class XSwipeTo extends StatefulWidget {
  final Color iconBackgroundColor;
  final Color backColor;
  final Widget thumb;
  final Widget content;
  final BorderRadius borderRadius;
  final SwipePosition initialPosition;
  final ValueChanged<SwipePosition> onChanged;
  final double horizintalPadding;
  final double circleHeight;
  final double circleWidth;
  const XSwipeTo(
      {Key key,
      @required this.iconBackgroundColor,
      @required this.backColor,
      this.thumb,
      this.content,
      @required this.borderRadius,
      this.initialPosition,
      @required this.onChanged,
      @required this.horizintalPadding,
      @required this.circleHeight,
      @required this.circleWidth})
      : super(key: key);

  @override
  XSwipeToState createState() => XSwipeToState();
}

class XSwipeToState extends State<XSwipeTo>
    with SingleTickerProviderStateMixin {
  final GlobalKey _containerKey = GlobalKey();
  final GlobalKey _positionedKey = GlobalKey();

  AnimationController _controller;
  Animation<double> _contentAnimation;
  Offset _start = Offset.zero;

  RenderBox get _positioned => _positionedKey.currentContext.findRenderObject();

  RenderBox get _container => _containerKey.currentContext.findRenderObject();

  @override
  void initState() {
    super.initState();
    _controller = AnimationController.unbounded(vsync: this);
    _contentAnimation = Tween<double>(begin: 1.0, end: 0.0)
        .animate(CurvedAnimation(parent: _controller, curve: Curves.easeOut));
    if (widget.initialPosition == SwipePosition.SwipeRight) {
      _controller.value = 1.0;
    }
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    //final theme = Theme.of(context);
    return SizedBox(
      width: double.infinity,
      height: 150.0,
      child: Stack(
        key: _containerKey,
        children: <Widget>[
          DecoratedBox(
            decoration: BoxDecoration(
                color: widget.backColor, borderRadius: widget.borderRadius),
            child: ClipRRect(
              clipper: _XSwipeToClipper(
                animation: _controller,
                borderRadius: widget.borderRadius,
              ),
              borderRadius: widget.borderRadius,
              child: SizedBox.expand(
                child: Padding(
                  padding: EdgeInsets.only(),
                  child: FadeTransition(
                    opacity: _contentAnimation,
                    child: widget.content,
                  ),
                ),
              ),
            ),
          ),
          AnimatedBuilder(
            animation: _controller,
            builder: (BuildContext context, Widget child) {
              return Align(
                alignment: Alignment((_controller.value * 2.0) - 1.0, 0.0),
                child: child,
              );
            },
            child: GestureDetector(
              onHorizontalDragStart: _onDragStart,
              onHorizontalDragUpdate: _onDragUpdate,
              onHorizontalDragEnd: _onDragEnd,
              child: Container(
                margin:
                    EdgeInsets.symmetric(horizontal: widget.horizintalPadding),
                key: _positionedKey,
                width: widget.circleWidth,
                height: widget.circleHeight,
                decoration: BoxDecoration(
                  shape: BoxShape.circle,
                  color: widget.iconBackgroundColor,
                ),
                child: widget.thumb,
              ),
            ),
          ),
        ],
      ),
    );
  }

  void _onDragStart(DragStartDetails details) {
    final pos = _positioned.globalToLocal(details.globalPosition);
    _start = Offset(pos.dx, 0.0);
    _controller.stop(canceled: true);
  }

  void _onDragUpdate(DragUpdateDetails details) {
    final pos = _container.globalToLocal(details.globalPosition) - _start;
    final extent = _container.size.width - _positioned.size.width;
    _controller.value = (pos.dx.clamp(0.0, extent) / extent);
  }

  void _onDragEnd(DragEndDetails details) {
    final extent = _container.size.width - _positioned.size.width;
    var fractionalVelocity = (details.primaryVelocity / extent).abs();
    if (fractionalVelocity < 0.5) {
      fractionalVelocity = 0.5;
    }
    SwipePosition result;
    double acceleration, velocity;
    if (_controller.value > 0.5) {
      acceleration = 0.5;
      velocity = fractionalVelocity;
      result = SwipePosition.SwipeRight;
    } else {
      acceleration = -0.5;
      velocity = -fractionalVelocity;
      result = SwipePosition.SwipeLeft;
    }
    final simulation = _SwipeSimulation(
      acceleration,
      _controller.value,
      1.0,
      velocity,
    );
    _controller.animateWith(simulation).then((_) {
      if (widget.onChanged != null) {
        widget.onChanged(result);
      }
    });
  }
}

class _SwipeSimulation extends GravitySimulation {
  _SwipeSimulation(
      double acceleration, double distance, double endDistance, double velocity)
      : super(acceleration, distance, endDistance, velocity);

  @override
  double x(double time) => super.x(time).clamp(0.0, 1.0);

  @override
  bool isDone(double time) {
    final _x = x(time).abs();
    return _x <= 0.0 || _x >= 1.0;
  }
}

class _XSwipeToClipper extends CustomClipper<RRect> {
  const _XSwipeToClipper({
    @required this.animation,
    @required this.borderRadius,
  })  : assert(animation != null && borderRadius != null),
        super(reclip: animation);

  final Animation<double> animation;
  final BorderRadius borderRadius;

  @override
  RRect getClip(Size size) {
    return borderRadius.toRRect(
      Rect.fromLTRB(
        size.width * animation.value,
        0.0,
        size.width,
        size.height,
      ),
    );
  }

  @override
  bool shouldReclip(_XSwipeToClipper oldClipper) => true;
}

==> firexcode-0.9.9.tar.gz: lib/src/Swipper/Swipe_To.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/physics.dart';

enum SwipePosition {
  SwipeLeft,
  SwipeRight,
}

class XSwipeTo extends StatefulWidget {
  final Color iconBackgroundColor;
  final Color backColor;
  final Widget? thumb;
  final Widget? content;
  final BorderRadius borderRadius;
  final SwipePosition? initialPosition;
  final ValueChanged<SwipePosition> onChanged;
  final double horizintalPadding;
  final double circleHeight;
  final double circleWidth;
  const XSwipeTo(
      {Key? key,
      required this.iconBackgroundColor,
      required this.backColor,
      this.thumb,
      this.content,
      required this.borderRadius,
      this.initialPosition,
      required this.onChanged,
      required this.horizintalPadding,
      required this.circleHeight,
      required this.circleWidth})
      : super(key: key);

  @override
  XSwipeToState createState() => XSwipeToState();
}

class XSwipeToState extends State<XSwipeTo>
    with SingleTickerProviderStateMixin {
  final GlobalKey _containerKey = GlobalKey();
  final GlobalKey _positionedKey = GlobalKey();

  AnimationController? _controller;
  late Animation<double> _contentAnimation;
  Offset _start = Offset.zero;

  RenderBox? get _positioned =>
      _positionedKey.currentContext!.findRenderObject() as RenderBox?;

  RenderBox? get _container =>
      _containerKey.currentContext!.findRenderObject() as RenderBox?;

  @override
  void initState() {
    super.initState();
    _controller = AnimationController.unbounded(vsync: this);
    _contentAnimation = Tween<double>(begin: 1.0, end: 0.0)
        .animate(CurvedAnimation(parent: _controller!, curve: Curves.easeOut));
    if (widget.initialPosition == SwipePosition.SwipeRight) {
      _controller!.value = 1.0;
    }
  }

  @override
  void dispose() {
    _controller!.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    //final theme = Theme.of(context);
    return SizedBox(
      width: double.infinity,
      height: 150.0,
      child: Stack(
        key: _containerKey,
        children: <Widget>[
          DecoratedBox(
            decoration: BoxDecoration(
                color: widget.backColor, borderRadius: widget.borderRadius),
            child: ClipRRect(
              clipper: _XSwipeToClipper(
                animation: _controller,
                borderRadius: widget.borderRadius,
              ),
              borderRadius: widget.borderRadius,
              child: SizedBox.expand(
                child: Padding(
                  padding: EdgeInsets.only(),
                  child: FadeTransition(
                    opacity: _contentAnimation,
                    child: widget.content,
                  ),
                ),
              ),
            ),
          ),
          AnimatedBuilder(
            animation: _controller!,
            builder: (BuildContext context, Widget? child) {
              return Align(
                alignment: Alignment((_controller!.value * 2.0) - 1.0, 0.0),
                child: child,
              );
            },
            child: GestureDetector(
              onHorizontalDragStart: _onDragStart,
              onHorizontalDragUpdate: _onDragUpdate,
              onHorizontalDragEnd: _onDragEnd,
              child: Container(
                margin:
                    EdgeInsets.symmetric(horizontal: widget.horizintalPadding),
                key: _positionedKey,
                width: widget.circleWidth,
                height: widget.circleHeight,
                decoration: BoxDecoration(
                  shape: BoxShape.circle,
                  color: widget.iconBackgroundColor,
                ),
                child: widget.thumb,
              ),
            ),
          ),
        ],
      ),
    );
  }

  void _onDragStart(DragStartDetails details) {
    final pos = _positioned!.globalToLocal(details.globalPosition);
    _start = Offset(pos.dx, 0.0);
    _controller!.stop(canceled: true);
  }

  void _onDragUpdate(DragUpdateDetails details) {
    final pos = _container!.globalToLocal(details.globalPosition) - _start;
    final extent = _container!.size.width - _positioned!.size.width;
    _controller!.value = (pos.dx.clamp(0.0, extent) / extent);
  }

  void _onDragEnd(DragEndDetails details) {
    final extent = _container!.size.width - _positioned!.size.width;
    var fractionalVelocity = (details.primaryVelocity! / extent).abs();
    if (fractionalVelocity < 0.5) {
      fractionalVelocity = 0.5;
    }
    SwipePosition result;
    double acceleration, velocity;
    if (_controller!.value > 0.5) {
      acceleration = 0.5;
      velocity = fractionalVelocity;
      result = SwipePosition.SwipeRight;
    } else {
      acceleration = -0.5;
      velocity = -fractionalVelocity;
      result = SwipePosition.SwipeLeft;
    }
    final simulation = _SwipeSimulation(
      acceleration,
      _controller!.value,
      1.0,
      velocity,
    );
    _controller!.animateWith(simulation).then((_) {
      // if (widget.onChanged != null) {
      //   widget.onChanged(result);
      // }
      widget.onChanged(result);
    });
  }
}

class _SwipeSimulation extends GravitySimulation {
  _SwipeSimulation(
      double acceleration, double distance, double endDistance, double velocity)
      : super(acceleration, distance, endDistance, velocity);

  @override
  double x(double time) => super.x(time).clamp(0.0, 1.0);

  @override
  bool isDone(double time) {
    final _x = x(time).abs();
    return _x <= 0.0 || _x >= 1.0;
  }
}

class _XSwipeToClipper extends CustomClipper<RRect> {
  const _XSwipeToClipper({
    required this.animation,
    required this.borderRadius,
  })   : assert(animation != null && borderRadius != null),
        super(reclip: animation);

  final Animation<double>? animation;
  final BorderRadius? borderRadius;

  @override
  RRect getClip(Size size) {
    return borderRadius!.toRRect(
      Rect.fromLTRB(
        size.width * animation!.value,
        0.0,
        size.width,
        size.height,
      ),
    );
  }

  @override
  bool shouldReclip(_XSwipeToClipper oldClipper) => true;
}
